Utilities
---------

.. automodule:: pyvista.utilities

.. autofunction:: pyvista.set_error_output_file

.. autofunction:: pyvista.trans_from_matrix

.. autofunction:: pyvista.is_inside_bounds


Object Conversions
~~~~~~~~~~~~~~~~~~

.. autofunction:: pyvista.wrap

.. autofunction:: pyvista.is_pyvista_obj

.. autofunction:: pyvista.image_to_texture

.. autofunction:: pyvista.numpy_to_texture


File IO
~~~~~~~

.. autofunction:: pyvista.read

.. autofunction:: pyvista.read_exodus

.. autofunction:: pyvista.read_texture

.. autofunction:: pyvista.read_legacy


Mesh Creation
~~~~~~~~~~~~~

.. autofunction:: pyvista.lines_from_points

.. autofunction:: pyvista.vtk_points

.. autofunction:: pyvista.vector_poly_data

.. autofunction:: pyvista.fit_plane_to_points


Array Access
~~~~~~~~~~~~

.. autofunction:: pyvista.get_scalar

.. autofunction:: pyvista.convert_array

.. autofunction:: pyvista.point_scalar

.. autofunction:: pyvista.cell_scalar

.. autofunction:: pyvista.get_vtk_type

.. autofunction:: pyvista.vtk_bit_array_to_char

.. autofunction:: pyvista.convert_string_array
